@@ -13,16 +13,16 @@ else
 fi
 
 if [ -n "$LD_LIBRARY_PATH" ]; then
-	export LD_LIBRARY_PATH="$MEE_ROOT/lib:$LD_LIBRARY_PATH:/opt/qtm12/lib"
+	export LD_LIBRARY_PATH="$MEE_ROOT/lib:/opt/qtm12/lib:$LD_LIBRARY_PATH"
 else
 	export LD_LIBRARY_PATH="$MEE_ROOT/lib:/opt/qtm12/lib"
 fi
 
-if [ -n "$LD_PRELOAD" ]; then
-	export LD_PRELOAD="$MEE_ROOT/lib/libstdc++.so.6:$LD_PRELOAD"
-else
-	export LD_PRELOAD="$MEE_ROOT/lib/libstdc++.so.6"
-fi
+#if [ -n "$LD_PRELOAD" ]; then
+#	export LD_PRELOAD="$MEE_ROOT/lib/libstdc++.so.6:$LD_PRELOAD"
+#else
+#	export LD_PRELOAD="$MEE_ROOT/lib/libstdc++.so.6"
+#fi
 
 
 if [ -n "$QML_IMPORT_PATH" ]; then
